[evolution-data-server/mmeeks-gdbus-import] rename missing enum



commit 90de3cd5e9bb2a78fdecde6ce01ea9cac7eb63c0
Author: Michael Meeks <michael meeks novell com>
Date:   Fri Feb 26 16:22:16 2010 +0000

    rename missing enum

 edbus/edbusconnection.c    |   22 +++++++++++-----------
 edbus/edbusconnection.h    |   10 +++++-----
 edbus/edbusenums.h         |    8 ++++----
 edbus/edbusenumtypes.c     |    4 ++--
 edbus/edbusnameowning.c    |   14 +++++++-------
 edbus/edbusnameowning.h    |    6 +++---
 edbus/edbusnamewatching.c  |    2 +-
 edbus/edbusnamewatching.h  |    2 +-
 edbus/edbusproxywatching.c |    2 +-
 edbus/edbusproxywatching.h |    2 +-
 edbus/example-own-name.c   |    2 +-
 11 files changed, 37 insertions(+), 37 deletions(-)
---
diff --git a/edbus/edbusconnection.c b/edbus/edbusconnection.c
index 918c5c5..49af86c 100644
--- a/edbus/edbusconnection.c
+++ b/edbus/edbusconnection.c
@@ -54,7 +54,7 @@ struct _EDBusConnectionPrivate
   DBusConnection *dbus_1_connection;
 
   /* construct properties */
-  GBusType        bus_type;
+  EDBusType        bus_type;
   gchar          *address;
   gboolean        is_private;
 
@@ -467,7 +467,7 @@ e_dbus_connection_init (EDBusConnection *connection)
  * #G_BUS_TYPE_NONE if the connection is not to a message
  * bus.
  **/
-GBusType
+EDBusType
 e_dbus_connection_get_bus_type (EDBusConnection *connection)
 {
   g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), G_BUS_TYPE_NONE);
@@ -708,7 +708,7 @@ e_dbus_connection_constructor (GType                  type,
     {
       if (g_strcmp0 (construct_properties[n].pspec->name, "bus-type") == 0)
         {
-          GBusType bus_type;
+          EDBusType bus_type;
           const gchar *starter_bus;
 
           bus_type = g_value_get_enum (construct_properties[n].value);
@@ -954,7 +954,7 @@ _e_dbus_connection_new_for_dbus_1_connection (DBusConnection  *dbus_1_connection
 
 /**
  * e_dbus_connection_bus_get_sync:
- * @bus_type: A #GBusType.
+ * @bus_type: A #EDBusType.
  * @cancellable: A #GCancellable or %NULL.
  * @error: Return location for error or %NULL.
  *
@@ -973,7 +973,7 @@ _e_dbus_connection_new_for_dbus_1_connection (DBusConnection  *dbus_1_connection
  * Returns: A #EDBusConnection or %NULL if @error is set. Free with g_object_unref().
  **/
 EDBusConnection *
-e_dbus_connection_bus_get_sync (GBusType            bus_type,
+e_dbus_connection_bus_get_sync (EDBusType            bus_type,
                                 GCancellable       *cancellable,
                                 GError            **error)
 {
@@ -993,7 +993,7 @@ e_dbus_connection_bus_get_sync (GBusType            bus_type,
 
 /**
  * e_dbus_connection_bus_get:
- * @bus_type: A #GBusType.
+ * @bus_type: A #EDBusType.
  * @cancellable: A #GCancellable or %NULL.
  * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
  * @user_data: The data to pass to @callback.
@@ -1011,7 +1011,7 @@ e_dbus_connection_bus_get_sync (GBusType            bus_type,
  * e_dbus_connection_bus_get_sync() for the synchronous version.
  **/
 void
-e_dbus_connection_bus_get (GBusType             bus_type,
+e_dbus_connection_bus_get (EDBusType             bus_type,
                            GCancellable        *cancellable,
                            GAsyncReadyCallback  callback,
                            gpointer             user_data)
@@ -1064,7 +1064,7 @@ e_dbus_connection_bus_get_finish (GAsyncResult  *res,
 
 /**
  * e_dbus_connection_bus_get_private_sync:
- * @bus_type: A #GBusType.
+ * @bus_type: A #EDBusType.
  * @cancellable: A #GCancellable or %NULL.
  * @error: Return location for error or %NULL.
  *
@@ -1074,7 +1074,7 @@ e_dbus_connection_bus_get_finish (GAsyncResult  *res,
  * Returns: A #EDBusConnection. Free with g_object_unref().
  **/
 EDBusConnection *
-e_dbus_connection_bus_get_private_sync (GBusType        bus_type,
+e_dbus_connection_bus_get_private_sync (EDBusType        bus_type,
                                         GCancellable   *cancellable,
                                         GError        **error)
 {
@@ -1095,7 +1095,7 @@ e_dbus_connection_bus_get_private_sync (GBusType        bus_type,
 
 /**
  * e_dbus_connection_bus_get_private:
- * @bus_type: A #GBusType.
+ * @bus_type: A #EDBusType.
  * @cancellable: A #GCancellable or %NULL.
  * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
  * @user_data: The data to pass to @callback.
@@ -1114,7 +1114,7 @@ e_dbus_connection_bus_get_private_sync (GBusType        bus_type,
  * version.
  **/
 void
-e_dbus_connection_bus_get_private (GBusType             bus_type,
+e_dbus_connection_bus_get_private (EDBusType             bus_type,
                                    GCancellable        *cancellable,
                                    GAsyncReadyCallback  callback,
                                    gpointer             user_data)
diff --git a/edbus/edbusconnection.h b/edbus/edbusconnection.h
index 4ef6b65..4476b85 100644
--- a/edbus/edbusconnection.h
+++ b/edbus/edbusconnection.h
@@ -94,26 +94,26 @@ EDBusConnection *e_dbus_connection_new_sync                   (const gchar
                                                                GCancellable       *cancellable,
                                                                GError            **error);
 
-void             e_dbus_connection_bus_get                    (GBusType             bus_type,
+void             e_dbus_connection_bus_get                    (EDBusType             bus_type,
                                                                GCancellable        *cancellable,
                                                                GAsyncReadyCallback  callback,
                                                                gpointer             user_data);
 EDBusConnection *e_dbus_connection_bus_get_finish             (GAsyncResult        *res,
                                                                GError             **error);
-EDBusConnection *e_dbus_connection_bus_get_sync               (GBusType            bus_type,
+EDBusConnection *e_dbus_connection_bus_get_sync               (EDBusType            bus_type,
                                                                GCancellable       *cancellable,
                                                                GError            **error);
 
-void             e_dbus_connection_bus_get_private            (GBusType             bus_type,
+void             e_dbus_connection_bus_get_private            (EDBusType             bus_type,
                                                                GCancellable        *cancellable,
                                                                GAsyncReadyCallback  callback,
                                                                gpointer             user_data);
 EDBusConnection *e_dbus_connection_bus_get_private_finish     (GAsyncResult        *res,
                                                                GError             **error);
-EDBusConnection *e_dbus_connection_bus_get_private_sync       (GBusType            bus_type,
+EDBusConnection *e_dbus_connection_bus_get_private_sync       (EDBusType            bus_type,
                                                                GCancellable       *cancellable,
                                                                GError            **error);
-GBusType         e_dbus_connection_get_bus_type               (EDBusConnection    *connection);
+EDBusType         e_dbus_connection_get_bus_type               (EDBusConnection    *connection);
 const gchar     *e_dbus_connection_get_address                (EDBusConnection    *connection);
 const gchar     *e_dbus_connection_get_unique_name            (EDBusConnection    *connection);
 gboolean         e_dbus_connection_get_is_private             (EDBusConnection    *connection);
diff --git a/edbus/edbusenums.h b/edbus/edbusenums.h
index 086edb9..d9a50c8 100644
--- a/edbus/edbusenums.h
+++ b/edbus/edbusenums.h
@@ -33,7 +33,7 @@
 G_BEGIN_DECLS
 
 /**
- * GBusType:
+ * EDBusType:
  * @G_BUS_TYPE_NONE: Not a message bus connection.
  * @G_BUS_TYPE_SESSION: The login session message bus.
  * @G_BUS_TYPE_SYSTEM: The system-wide message bus.
@@ -47,10 +47,10 @@ typedef enum
   G_BUS_TYPE_SESSION = 0,
   G_BUS_TYPE_SYSTEM  = 1,
   G_BUS_TYPE_STARTER = 2
-} GBusType;
+} EDBusType;
 
 /**
- * GBusNameOwnerFlags:
+ * EDBusNameOwnerFlags:
  * @G_BUS_NAME_OWNER_FLAGS_NONE: No flags set.
  * @G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT: Allow another message connection to take the name.
  * @G_BUS_NAME_OWNER_FLAGS_REPLACE: If another message bus connection
@@ -64,7 +64,7 @@ typedef enum
   G_BUS_NAME_OWNER_FLAGS_NONE = 0,                    /*< nick=none >*/
   G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT = (1<<0),  /*< nick=allow-replacement >*/
   G_BUS_NAME_OWNER_FLAGS_REPLACE = (1<<1),            /*< nick=replace >*/
-} GBusNameOwnerFlags;
+} EDBusNameOwnerFlags;
 
 /**
  * EDBusProxyFlags:
diff --git a/edbus/edbusenumtypes.c b/edbus/edbusenumtypes.c
index a853fa9..07e4a9d 100644
--- a/edbus/edbusenumtypes.c
+++ b/edbus/edbusenumtypes.c
@@ -100,7 +100,7 @@ g_bus_type_get_type (void)
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
-        g_enum_register_static (g_intern_static_string ("GBusType"), values);
+        g_enum_register_static (g_intern_static_string ("EDBusType"), values);
       g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
     }
 
@@ -121,7 +121,7 @@ g_bus_name_owner_flags_get_type (void)
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
-        g_flags_register_static (g_intern_static_string ("GBusNameOwnerFlags"), values);
+        g_flags_register_static (g_intern_static_string ("EDBusNameOwnerFlags"), values);
       g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
     }
 
diff --git a/edbus/edbusnameowning.h b/edbus/edbusnameowning.h
index 5835866..def7d17 100644
--- a/edbus/edbusnameowning.h
+++ b/edbus/edbusnameowning.h
@@ -56,16 +56,16 @@ typedef void (*GBusNameLostCallback) (EDBusConnection *connection,
                                       const gchar     *name,
                                       gpointer         user_data);
 
-guint e_bus_own_name                 (GBusType                  bus_type,
+guint e_bus_own_name                 (EDBusType                  bus_type,
                                       const gchar              *name,
-                                      GBusNameOwnerFlags        flags,
+                                      EDBusNameOwnerFlags        flags,
                                       GBusNameAcquiredCallback  name_acquired_handler,
                                       GBusNameLostCallback      name_lost_handler,
                                       gpointer                  user_data,
                                       GDestroyNotify            user_data_free_func);
 guint e_bus_own_name_on_connection   (EDBusConnection          *connection,
                                       const gchar              *name,
-                                      GBusNameOwnerFlags        flags,
+                                      EDBusNameOwnerFlags        flags,
                                       GBusNameAcquiredCallback  name_acquired_handler,
                                       GBusNameLostCallback      name_lost_handler,
                                       gpointer                  user_data,
diff --git a/edbus/edbusnamewatching.c b/edbus/edbusnamewatching.c
index da1886e..b51df55 100644
--- a/edbus/edbusnamewatching.c
+++ b/edbus/edbusnamewatching.c
@@ -451,7 +451,7 @@ connection_get_cb (GObject      *source_object,
  * e_bus_unwatch_name() to stop watching the name.
  **/
 guint
-e_bus_watch_name (GBusType                  bus_type,
+e_bus_watch_name (EDBusType                  bus_type,
                   const gchar              *name,
                   GBusNameAppearedCallback  name_appeared_handler,
                   GBusNameVanishedCallback  name_vanished_handler,
diff --git a/edbus/edbusnamewatching.h b/edbus/edbusnamewatching.h
index 760f0f6..c11f662 100644
--- a/edbus/edbusnamewatching.h
+++ b/edbus/edbusnamewatching.h
@@ -58,7 +58,7 @@ typedef void (*GBusNameVanishedCallback) (EDBusConnection *connection,
                                           gpointer         user_data);
 
 
-guint e_bus_watch_name   (GBusType                  bus_type,
+guint e_bus_watch_name   (EDBusType                  bus_type,
                           const gchar              *name,
                           GBusNameAppearedCallback  name_appeared_handler,
                           GBusNameVanishedCallback  name_vanished_handler,
diff --git a/edbus/edbusproxywatching.c b/edbus/edbusproxywatching.c
index aabe82f..8271fb5 100644
--- a/edbus/edbusproxywatching.c
+++ b/edbus/edbusproxywatching.c
@@ -329,7 +329,7 @@ on_name_vanished (EDBusConnection *connection,
  * e_bus_unwatch_proxy() to stop watching the remote object.
  **/
 guint
-e_bus_watch_proxy (GBusType                   bus_type,
+e_bus_watch_proxy (EDBusType                   bus_type,
                    const gchar               *name,
                    const gchar               *object_path,
                    const gchar               *interface_name,
diff --git a/edbus/edbusproxywatching.h b/edbus/edbusproxywatching.h
index 62c7c2f..6f0422f 100644
--- a/edbus/edbusproxywatching.h
+++ b/edbus/edbusproxywatching.h
@@ -63,7 +63,7 @@ typedef void (*GBusProxyVanishedCallback) (EDBusConnection *connection,
                                            const gchar     *name,
                                            gpointer         user_data);
 
-guint e_bus_watch_proxy   (GBusType                   bus_type,
+guint e_bus_watch_proxy   (EDBusType                   bus_type,
                            const gchar               *name,
                            const gchar               *object_path,
                            const gchar               *interface_name,
diff --git a/edbus/example-own-name.c b/edbus/example-own-name.c
index 6921552..96c5325 100644
--- a/edbus/example-own-name.c
+++ b/edbus/example-own-name.c
@@ -21,7 +21,7 @@ main (int argc, char *argv[])
 {
   guint owner_id;
   GMainLoop *loop;
-  GBusNameOwnerFlags flags;
+  EDBusNameOwnerFlags flags;
   gboolean opt_replace;
   gboolean opt_allow_replacement;
   gchar *opt_name;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/edbus/edbusnameowning.c b/edbus/edbusnameowning.c
index 9c1a941..ec995a2 100644
--- a/edbus/edbusnameowning.c
+++ b/edbus/edbusnameowning.c
@@ -57,7 +57,7 @@ typedef struct
 {
   volatile gint             ref_count;
   guint                     id;
-  GBusNameOwnerFlags        flags;
+  EDBusNameOwnerFlags        flags;
   gchar                    *name;
   GBusNameAcquiredCallback  name_acquired_handler;
   GBusNameLostCallback      name_lost_handler;
@@ -429,14 +429,14 @@ connection_get_cb (GObject      *source_object,
  * e_bus_own_name_on_connection:
  * @connection: A #EDBusConnection that has not been disconnected.
  * @name: The well-known name to own.
  * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired.
  * @name_lost_handler: Handler to invoke when @name is lost.
  * @user_data: User data to pass to handlers.
  * @user_data_free_func: Function for freeing @user_data or %NULL.
  *
  * Like e_bus_own_name() but takes a #EDBusConnection instead of a
- * #GBusType.
+ * #EDBusType.
  *
  * Returns: An identifier (never 0) that an be used with
  * e_bus_unown_name() to stop owning the name.
@@ -444,7 +444,7 @@ connection_get_cb (GObject      *source_object,
 guint
 e_bus_own_name_on_connection (EDBusConnection          *connection,
                               const gchar              *name,
-                              GBusNameOwnerFlags        flags,
+                              EDBusNameOwnerFlags        flags,
                               GBusNameAcquiredCallback  name_acquired_handler,
                               GBusNameLostCallback      name_lost_handler,
                               gpointer                  user_data,
@@ -495,7 +495,7 @@ e_bus_own_name_on_connection (EDBusConnection          *connection,
  * e_bus_own_name:
  * @bus_type: The type of bus to own a name on (can't be #G_BUS_TYPE_NONE).
  * @name: The well-known name to own.
  * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired.
  * @name_lost_handler: Handler to invoke when @name is lost.
  * @user_data: User data to pass to handlers.
@@ -536,9 +536,9 @@ e_bus_own_name_on_connection (EDBusConnection          *connection,
  * e_bus_unown_name() to stop owning the name.
  **/
 guint
-e_bus_own_name (GBusType                  bus_type,
+e_bus_own_name (EDBusType                  bus_type,
                 const gchar              *name,
-                GBusNameOwnerFlags        flags,
+                EDBusNameOwnerFlags        flags,
                 GBusNameAcquiredCallback  name_acquired_handler,
                 GBusNameLostCallback      name_lost_handler,
                 gpointer                  user_data,
@@ -429,14 +429,14 @@ connection_get_cb (GObject      *source_object,
  * @connection: A #EDBusConnection that has not been disconnected.
  * @name: The well-known name to own.
- * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
+ * @flags: A set of flags from the #EDBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired.
  * @name_lost_handler: Handler to invoke when @name is lost.
@@ -495,7 +495,7 @@ e_bus_own_name_on_connection (EDBusConnection          *connection,
  * @bus_type: The type of bus to own a name on (can't be #G_BUS_TYPE_NONE).
  * @name: The well-known name to own.
- * @flags: A set of flags from the #GBusNameOwnerFlags enumeration.
+ * @flags: A set of flags from the #EDBusNameOwnerFlags enumeration.
  * @name_acquired_handler: Handler to invoke when @name is acquired.
  * @name_lost_handler: Handler to invoke when @name is lost.